#!/bin/bash
#
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# Source location : http://normalize.nongnu.org/
#
# Last version          : 08/02/2007
#
# Dependance : audiofile,libmad,perl
#

#
# Quel package va tre construit
# 42 -> ZenWalk version 4.2 
#
softname='normalize'
softversion='0.7.7'
packageversion='48.1'

#
# ZenWalk standard: type CPUet architecture
#
# arch='i486' -> le compileur utilise seulement les instructions 80486
# cpu='i686'  -> optimisation fate pour PII et >
#
arch='i486'
cpu='i686'

#
# destination du package
#
prefix=/usr

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "gros" PC: 6 compilations  la fois
#
# numjobs='-j6'
#
# "lger" PC: 2 compilations  la fois
#
numjobs='-j2'

#
# paramtres pour compiler
#
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"

#
# preparer le rpertoire qui accueillera la compilation
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/src/$softname-$softversion

#
# mettre le slack-desc en place. 
#
cat <<EOF > $dest/install/slack-desc
         |-----handy-ruler------------------------------------------------------|
$softname: $softname is a tool for adjusting the volume of  audio files. 
$softname:
$softname: normalize is a tool for adjusting the volume of 
$softname: audio files to a standard level.
$softname: This is useful for things like creating mixed CD's and mp3 collections 
$softname: where different recording levels on different albums can cause 
$softname: the volume to vary greatly from song to song.
$softname:
$softname: 
$softname:
$softname: 
EOF

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
tar xzvf $srcpkg
cd $src

#
# configurer le package pour la compilation
#

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=$prefix \
      --sysconfdir=/etc \
      --localstatedir=/var/lib \

#
# "faire" le package package
#
    make $numjobs DESTDIR=$dest

#
# installer le package dans son rpertoire de destination
#
    make install DESTDIR=$dest

#
# ajout des fichiers de docs, infos, ...
#
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      ABOUT-NLS COPYING INSTALL NEWS README TODO THANKS\
      $dest/usr/doc/$softname-$softversion

#
# Stripper les xcutables
# (Commenter ces lignes si besoin d'infos de dbuggage)
#
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#
# Compresser les pages Man
#
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

#
# Mettre le zenbuild  sa place
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

#
# fixer les permissions
#
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#
# fabriquer le zenpackage
#
cd $dest
makepkg -l y -c n $dest.tgz

#
# produire la signature md5 du package
#
cd $buildir
md5sum $package.tgz > $package.md5

#
# fabriquer le fichier dpendance
#
requiredbuilder -z $package.tgz > $package.dep
